@@ -427,7 +427,7 @@ class Watershed(Segmenter):
 
     def __init__(self, data, markers=None, connectivity=1, offset=None, mask=None,
                  compactness=0, watershed_line=False, dist_func='euclidean',
-                 window=1, min_size=20, n_proc=8):
+                 window=1, min_size=20, n_proc=8, grad=None):
         """Sets additional parameters for the watershed algorithm.
 
         For most parameters see the skimage.segmentation.watershed documentation.
@@ -457,6 +457,7 @@ class Watershed(Segmenter):
             window (int, optional): the size of window to find neighbors for RCMG. Defaults to 1.
             min_size (int, optional): The minimum number of pixels in a region. Defaults to 20.
             n_proc (int, optional): the number of processes for Pool for calculating gradient. Defaults to 8.
+            grad (ndarray, option): if you have precomputed the gradient, you can pass it in here.
         """
         super().__init__(data)
         self.set_markers(markers)
@@ -469,6 +470,11 @@ class Watershed(Segmenter):
         self.set_window(window)
         self.set_min_size(min_size)
         self.set_n_proc(n_proc)
+        self.set_grad(grad)
+
+    def set_grad(self, grad):
+        self.grad = grad
+        self._change = True
 
     def set_markers(self, markers):
         self.markers = markers
@@ -583,6 +589,13 @@ class Watershed(Segmenter):
             grad[x, y] = r[0]
         return grad
 
+    def get_grad(self, img=None):
+        img = super().segment(img)
+        if not hasattr(self, 'grad') or self.grad is None:
+            self.grad = self._gradient(img, self.window, self.n_proc)
+        return self.grad
+
+
     def segment(self, img=None):
         """Segments the image using the watershed algorithm.
 
@@ -593,7 +606,7 @@ class Watershed(Segmenter):
             ndarray: 2D array with labeled segments.
         """
         img = super().segment(img)
-        self.grad = self._gradient(img, self.window, self.n_proc)
+        self.grad = self.get_grad(img)
         seg = segmentation.watershed(self.grad, markers=self.markers, connectivity=self.connectivity,
                                      offset=self.offset, mask=self.mask,
                                      compactness=self.compactness,
